@@ -55,6 +55,7 @@ CCanvas::CCanvas(CMainWindow * parent)
 , trkpt1st(0)
 , trkpt2nd(0)
 , headingPixmap(":/pics/heading.png")
+, isZoom(false)
 {
     setMouseTracking(true);
     setFocusPolicy(Qt::StrongFocus);
@@ -101,7 +102,6 @@ CCanvas::CCanvas(CMainWindow * parent)
 
     contextMenu = new QMenu(this);
     contextMenu->addAction(QIcon(":/icons/iconEditPaste16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()));
-
 }
 
 
@@ -126,7 +126,7 @@ void CCanvas::print(QPrinter& printer)
     p.scale(s,s);
     p.setClipRegion(rect());
     p.setFont(gpResources->getMapFont());
-    draw(p,false);
+    draw(p,true);
     p.end();
 
 }
@@ -135,6 +135,7 @@ void CCanvas::print(QPrinter& printer)
 void CCanvas::slotIncreaseDetails()
 {
     timerZoomDetailDelay->stop();
+    isZoom = false;
     map->setEasyDraw(false);
     update();
 }
@@ -218,6 +219,7 @@ void CCanvas::zoom(const QRectF& area)
 
 void CCanvas::zoom(bool in, const QPoint& p)
 {
+    isZoom = true;
     map->setEasyDraw(true);
     map->zoom(in, p);
     timerZoomDetailDelay->start(500);
@@ -320,7 +322,6 @@ void CCanvas::setMouseMode(mouse_mode_e mode)
 void CCanvas::resizeEvent(QResizeEvent * e)
 {
     map->resize(e->size());
-
     infoScreen->move(e->size().width() - 210,10);
     infoScreen->setMaximumHeight(e->size().height() - 20);
 }
@@ -334,8 +335,8 @@ void CCanvas::paintEvent(QPaintEvent * e)
     p.begin(this);
     p.fillRect(rect(),Qt::white);
     p.setFont(gpResources->getMapFont());
-    p.setRenderHint(QPainter::Antialiasing,true);
-    draw(p,true);
+    p.setRenderHint(QPainter::Antialiasing,false);
+    draw(p,false);
     p.end();
 
 }
@@ -345,7 +346,10 @@ void CCanvas::draw(QPainter& p, bool buffered)
 {
     map->draw(p, buffered);
 
-    drawTracks(p);
+    if(!moveMap && !isZoom) {
+        drawTracks(p);
+    }
+
     drawWaypoints(p);
     drawSelectedMaps(p);
     drawZoomRect(p);
@@ -354,6 +358,7 @@ void CCanvas::draw(QPainter& p, bool buffered)
     drawCacheSearchRadius(p);
     drawLiveLogPosition(p);
     drawRoutes(p);
+
 }
 
 
@@ -422,10 +427,14 @@ void CCanvas::drawTracks(QPainter& p)
         }
         else {
             // draw normal track
-            p.setPen(QPen((*track)->getColor(),3));
+            QPen pen((*track)->getColor(),3);
+            pen.setCapStyle(Qt::RoundCap);
+            pen.setJoinStyle(Qt::RoundJoin);
+            p.setPen(pen);
             p.drawPolyline(line);
             p.setPen(Qt::white);
             p.drawPolyline(line);
+
         }
         ++track;
     }
@@ -437,22 +446,26 @@ void CCanvas::drawTracks(QPainter& p)
         QPolygon& line = (*track)->polyline();
 
         // draw skunk line
-        p.setPen(QPen((*track)->getColor(),5));
+        QPen pen((*track)->getColor(),5);
+        pen.setCapStyle(Qt::RoundCap);
+        pen.setJoinStyle(Qt::RoundJoin);
+        p.setPen(pen);
         p.drawPolyline(line);
         p.setPen(Qt::white);
         p.drawPolyline(line);
 
+
         // draw bubbles
         QPoint pt;
+        p.setPen((*track)->getColor());
+        p.setBrush(Qt::white);
         foreach(pt,line) {
-            p.setPen((*track)->getColor());
-            p.setBrush(Qt::white);
             p.drawEllipse(pt.x() - 2 ,pt.y() - 2,5,5);
 
         }
+        p.setPen(Qt::black);
+        p.setBrush(Qt::red);
         foreach(pt,selected) {
-            p.setPen(Qt::black);
-            p.setBrush(Qt::red);
             p.drawEllipse(pt.x() - 3 ,pt.y() - 3,7,7);
 
         }
@@ -605,9 +618,9 @@ void CCanvas::drawWaypoints(QPainter& p)
         p.drawPixmap(pt2 + QPoint(-7,-7),(*wpt)->icon);
         if(!wptIsMoving) {
             drawText((*wpt)->ident,p,pt2 + QPoint(0,-20));
-/*            p.setPen(Qt::darkBlue);
-            p.setBrush(Qt::darkBlue);
-            p.drawText(pt2 + QPoint(11,-8),(*wpt)->ident);*/
+            /*            p.setPen(Qt::darkBlue);
+                        p.setBrush(Qt::darkBlue);
+                        p.drawText(pt2 + QPoint(11,-8),(*wpt)->ident);*/
         }
         ++wpt;
     }
@@ -967,7 +980,7 @@ void CCanvas::drawRoutePolygon(CGarminRoute * route, bool isActRoute, QPainter&
         p.drawPolyline(line);
 
         QPoint pt;
-        foreach(pt, line){
+        foreach(pt, line) {
             p.drawPixmap(pt - QPoint(7,7), route->getIcon());
         }
     }
@@ -1028,18 +1041,9 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
     m_lon = u;
     m_lat = v;
 
-    qint32 degN,degE;
-    double minN,minE;
-
-    GPS_Math_Deg_To_DegMin(v, &degN, &minN);
-
-    GPS_Math_Deg_To_DegMin(u, &degE, &minE);
-
-    QString str,lat,lng;
-    lat = degN < 0 ? "S" : "N";
-    lng = degE < 0 ? "W" : "E";
-    str.sprintf(" %s%02d\260 %06.3f %s%03d\260 %06.3f ",lat.toUtf8().data(),abs(degN),minN,lng.toUtf8().data(),abs(degE),minE);
+    QString str;
 
+    GPS_Math_Deg_To_Str(u,v,str);
     coord->setText(str);
 
 }
@@ -1577,7 +1581,7 @@ void CCanvas::mouseReleaseDelRte(QMouseEvent * /*e*/)
 
 void CCanvas::wheelEvent(QWheelEvent * e)
 {
-    zoom((e->delta() < 0), e->pos());
+    zoom(gpResources->getFlipMouseWheel() ? (e->delta() > 0) : (e->delta() < 0), e->pos());
 }
 
 
@@ -1655,6 +1659,7 @@ void CCanvas::slotCopyPosition()
     clipboard->setText(coord->text());
 }
 
+
 void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center)
 {
     QFont           f = gpResources->getMapFont();
